/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2009 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                                                          *
*********************************************************************************
* Id: fxmoviemanager.h,   v 3.2                    2008/01/01                   *
*********************************************************************************
* This program is free software; you can redistribute it and/or modify          *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* This program is distributed in the hope that it will be useful,               *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/
#ifndef FXMOVIEMANAGER_H
#define FXMOVIEMANAGER_H

// #define HAVE_LIBFOX_1_6
// #define HAVE_LIBFOX_1_7
#include <signal.h>

//! the main program class. Here, is to be defined if using either fox-1.6 or
//! fox-1.7 development libraries.

class PropertiesDialog;
class MimeTypeDialog;

class FXMovieManager : public FXMainWindow {
	FXDECLARE(FXMovieManager)

private:
	FXMovieManager() {}

protected:
	// declare dialog classes
	PropertiesDialog *properties;
	MimeTypeDialog 	*mimetype;
	// logo
	FXIcon		*logoicon;
	// themes buttons
	FXIcon		*audioicon;
	FXIcon		*createicon; 
	FXIcon		*decreaseicon; 
	FXIcon		*deleteicon; 
	FXIcon		*deletehiddenicon; 
	FXIcon		*downicon;
	FXIcon		*dropicon; 
	FXIcon		*hiddenicon;
	FXIcon		*hideicon; 
	FXIcon		*increaseicon; 
	FXIcon		*loopicon;
	FXIcon		*openicon; 
	FXIcon		*pauseicon;
	FXIcon		*playicon;
	FXIcon		*quiticon;
	FXIcon     	*recreateicon; 
	FXIcon     	*showicon; 
	FXIcon     	*stopicon;
	FXIcon		*upicon;
	FXIcon     	*videoouticon;
	FXIcon     	*videosizeicon;
	FXIcon     	*videozoomicon;
	FXIcon     	*videoicon;
	FXIcon		*detlisticon;
	FXIcon     	*icnlisticon;
	// menus buttons
	FXIcon	   	*m_bugicon;
	FXIcon	   	*m_upicon;
	FXIcon	   	*m_downicon;
	FXIcon	   	*m_appendicon;
	FXIcon	   	*m_accepticon;
	FXIcon	   	*m_cancelicon;
	FXIcon	   	*m_propicon;
	FXIcon	   	*m_copyicon;
	FXIcon	   	*m_moveicon;
	FXIcon	   	*m_renameicon;
	FXIcon	   	*m_archiveicon;
	FXIcon	   	*m_mapicon;
	FXIcon	   	*m_unmapicon;
	FXIcon	   	*m_deleteicon;
	FXIcon	   	*m_refreshicon;
	FXIcon	   	*m_renamediricon;
	FXIcon	   	*m_showhiddenicon;

	// Menus
	FXMenuBar 	*menubar;           
	FXMenuPane 	*popupmenu;         
	FXMenuPane 	*videosizemenu;
	FXMenuPane 	*videooutmenu;
	FXMenuPane 	*archivemenu;
	FXMenuPane 	*compressmenu;

	FXLabel 	*playlistlabel;

	FXSplitter 	*splitter1;
	FXSplitter 	*splitter2;

	FXHorizontalFrame *listframe;   // the list frame	
	FXTable		*table;	
	FXVerticalFrame *listbuttonframe;

	FXVerticalFrame *dirframe;
	FXHorizontalFrame *filebuttonframe;
	FXVerticalFrame *fileframe;
	FXVerticalFrame *vbuttonframe;
	FXHorizontalFrame *sizeframe;
	FXHorizontalFrame *switchframe;
	FXHorizontalFrame *progressframe;

	FXStatusBar 	*statusbar;

	FXSlider 	*speedslider;
	FXSlider 	*volumeslider;

	FXRealSpinner 	*seekspinner;

	FXDirList  	*dirlist;
	FXFileList 	*filelist;

	FXFileDict 	*associations;	// File associations

	FXTextField 	*seekposition1;
	FXTextField 	*seekposition2;
	FXTextField 	*seekposition3;
	FXTextField 	*seekposition4;
	FXTextField 	*endposition1;
	FXTextField 	*endposition2;
	FXTextField 	*endposition3;
	FXTextField 	*endposition4;

	FXTextField 	*clock;

	FXProgressBar 	*progressbar;
	
	FXButton 	*quitbutton;
	FXButton 	*openbutton;
	FXButton 	*playbutton;
	FXButton 	*pausebutton;
	FXButton 	*stopbutton;

	FXToggleButton 	*dropbutton;
	FXToggleButton 	*audiobutton;
	FXToggleButton 	*loopbutton;
	FXToggleButton 	*zoombutton;
	FXToggleButton 	*hidebutton;
	FXToggleButton 	*selectbutton;
	FXToggleButton 	*widebutton;
	FXMenuButton 	*videosizebutton;
	FXMenuButton 	*videooutbutton;

	FXFont          *bodyfont;

protected:

  	FXColor 	theme_fxmmbase;
  	FXColor 	theme_fxmmborder;
  	FXColor 	theme_fxmmfore;
  	FXColor 	theme_fxmmselfore;
  	FXColor 	theme_fxmmmenufore;
  	FXColor 	theme_fxmmtipfore;
  	FXColor 	theme_fxmmback;
  	FXColor 	theme_fxmmselback;
  	FXColor 	theme_fxmmmenuback;
  	FXColor 	theme_fxmmtipback;
  	FXColor 	theme_fxmmhilite;
  	FXColor 	theme_fxmmshadow;

	FXString 	theme;
	FXString 	currentdir; 
	FXString 	filename;
	FXString 	language;
	FXString 	terminal;
  	FXString 	fontspec;

	FXString 	s_play;
	FXString 	s_command;
	FXString 	s_video;
	FXString 	s_size;
	FXString 	s_full;
	FXString 	s_loop;
	FXString 	s_audio;
	FXString 	s_frame;
	FXString 	s_list;
	FXString 	s_listshow;

	FXString 	currentInfo;
	FXString 	currentFifo;
	FXString 	removeTempFifo;
	FXString 	createTempFifo;

	FXString 	grepvideo;
	FXString 	grepaudio;

	FXString 	quitbuttontext;
	FXString 	openbuttontext;
	FXString 	stopbuttontext;
	FXString 	pausebuttontext;
	FXString 	playbuttontext;
	FXString 	speedbuttontext;
	FXString 	audiobuttontext1;
	FXString 	audiobuttontext2;
	FXString 	dropbuttontext1;
	FXString 	dropbuttontext2;
	FXString 	loopbuttontext1;
	FXString 	loopbuttontext2;
	FXString 	zoombuttontext1;
	FXString 	zoombuttontext2;
	FXString 	hidebuttontext1;
	FXString 	hidebuttontext2;
	FXString 	outputbuttontext;
	FXString 	sizebuttontext;
	FXString 	videobuttontext;
	FXString 	confbuttontext;
	FXString 	upbuttontext;
	FXString 	downbuttontext;
	FXString 	slistbuttontext;
	FXString 	olistbuttontext;
  	FXString 	allbuttontext1;
	FXString 	allbuttontext2;
	FXString 	createbuttontext;
	FXString 	recreatebuttontext;
  	FXString 	widebuttontext1;
	FXString 	widebuttontext2;
	FXString 	deletebuttontext;
	FXString 	clearbuttontext;
	FXString 	increasebuttontext;
	FXString 	decreasebuttontext;
	FXString 	icnlisttext;
	FXString 	detlisttext;

	FXint 		i_video;
	FXint 		i_size;
	FXint 		imgw;
	FXint 		imgh;
	FXint 		numtableitems;
	FXint		firstcolwidth;
	FXint		fxmmwheellines;

	FXbool 		listshow;
	FXbool 		isrunning;
	FXbool		widescreen;

  	// ffmpegthumbnailer options
  	FXint     thumbnailSize;
  	FXint     imageQuality;
  	FXbool    filmStripOverlay;
  	FXbool    workaroundIssues;
  	FXbool    maintainAspectRatio;
  	FXbool    smartFrameSelection;



protected:
	FXint getNumTableNames() const;
	FXint getNumFilenames() const;
	FXString* getFilenames() const;
	FXString getDirectory() const;
	FXString returnPlaylist();

	FXbool savePlaylistTable(const FXString& filename);
	FXbool loadPlaylistTable(const FXString& filename);
	FXbool previewListMovie(const FXString& filename, FXint i);
	FXbool previewMovie(const FXString& filename, FXint i, FXint w, FXint h);
	FXbool createImageMovie(const FXString& filetoplay, const FXString& rootname);
	FXbool createInfoMovie(const FXString& filename);
	FXbool freeImageMemory(FXint i);

	FXbool loadfile(const FXString& filename);
	FXbool readConfig();
	FXbool themeSelection();
	FXbool languageSelection();
	void getFilelistSelection();
	void appendFiledialogSelection();
	void insertFiledialogSelection();
	void resetTable();
	void selectAll();
	void deselectMainDir();
	void scanFileName(int ret, const char *virname, struct cl_engine *engine, FXString& filetoscan, FXint i);
	void languageEN();
	void languageIT();
	void languageFR();
	void languageDE();
	void languageES();
	void languageRU();
	void themeDG();
	void themeSF();
	void themeCM();
	void quitAppFxmm();

public:
	FXMovieManager(FXApp *);
	virtual ~FXMovieManager();
	virtual void create();

	enum{
    	ID_CLOCKTIME = FXMainWindow::ID_LAST,
	ID_FILE,
	ID_AUDIO,
	ID_DROP,
	ID_FULL,
	ID_LOOP,
	ID_PLAY,
	ID_PAUSE,
	ID_STOP,
	ID_QUIT,
	ID_SAVELIST,
	ID_OPENLIST,
	ID_LIST,
	ID_TABLE,
	ID_MOVEUP,
	ID_MOVEDOWN,
	ID_APPEND,
	ID_INSERT,
	ID_DELETE,
	ID_SELECTALL,
	ID_CLEAR,
	ID_PUTBACK,
	ID_DIRECTORYLIST,
    	ID_UPDIRECTORY,
	ID_DIRDELETE,
	ID_NEWDIR,
	ID_DIRRENAME,
	ID_MAPHOST,
	ID_UNMAPHOST,
	ID_FILELIST,
	ID_FILECOPY,
	ID_FILESYMLINK,
	ID_FILEDELETE,
	ID_FILERENAME,
    	ID_COMPRESS_TAR,
    	ID_COMPRESS_GZ,
    	ID_COMPRESS_BZ,
    	ID_COMPRESS_7Z,
    	ID_COMPRESS_Z,
    	ID_EXTRACT,
	ID_SCANVIRUS,	
	ID_FILEPLAY,
	ID_FILEPAUSE,
	ID_FILESTOP,
	ID_FILEPREVIEW,
	ID_FORCEFILEPREVIEW,
	ID_WIDESCREEN,
	ID_INCFILEPREVIEW,
	ID_DECFILEPREVIEW,
	ID_CLEARPREVIEW,
	ID_TERMINAL,
    	ID_FILE_CREATED,
    	ID_FILE_MODIFIED,
    	ID_FILE_TYPE,
	ID_FILE_MIMETYPE,
	ID_FILE_COMMAND,
    	ID_FILE_LOCATION,
    	ID_FILE_SIZE,
    	ID_FILE_DESC,
	ID_VIDEO_ASPECT,
	ID_AUDIO_FORMAT,
	ID_PROPERTIES,
	ID_MIMETYPE,
	ID_OPEN,
    	ID_OPENWITH,
    	ID_READOWNER,
    	ID_WRITEOWNER,
    	ID_EXECUTEOWNER,
    	ID_READGROUP,
    	ID_WRITEGROUP,
    	ID_EXECUTEGROUP,
    	ID_READOTHER,
    	ID_WRITEOTHER,
    	ID_EXECUTEOTHER,
    	ID_SETUID,
    	ID_SETGID,
    	ID_STICKY,
    	ID_OWNER,
    	ID_GROUP,
	ID_SIZE_0,
	ID_SIZE_1,
	ID_SIZE_2,
	ID_SIZE_3,
	ID_SIZE_4,
	ID_SIZE_5,
	ID_SIZE_6,
	ID_SIZE_7,
	ID_SIZE_8,
	ID_SIZE_9,
	ID_VIDEO_1,
	ID_VIDEO_2,
	ID_VIDEO_3,
	ID_VIDEO_4,
	ID_VIDEO_5,
	ID_VIDEO_6,
	ID_VIDEO_7,
	ID_VIDEO_8,
	ID_VIDEO_9,
	ID_LAST,
	};

public:
	// clock
  	long onClock(FXObject*,FXSelector,void*);
	// player button commands
	long onCmdQuit(FXObject *,FXSelector,void *);
	long onCmdFile(FXObject *,FXSelector,void *);
	long onCmdAudio(FXObject *,FXSelector,void *);
	long onCmdPlay(FXObject *,FXSelector,void *);
	long onCmdPause(FXObject *,FXSelector,void *);
	long onCmdStop(FXObject *,FXSelector,void *);
	long onCmdDrop(FXObject *,FXSelector,void *);
	long onCmdFull(FXObject *,FXSelector,void *);
	long onCmdLoop(FXObject *,FXSelector,void *);
	long onCmdSizeSwitch(FXObject* sender,FXSelector sel,void* ptr);
	long onUpdSizeSwitch(FXObject* sender,FXSelector sel,void* ptr);
	long onCmdVideoSwitch(FXObject* sender,FXSelector sel,void* ptr);
	long onUpdVideoSwitch(FXObject* sender,FXSelector sel,void* ptr);
	// table
	long onCmdAppend(FXObject*,FXSelector,void*);
	long onCmdInsert(FXObject*,FXSelector,void*);
	long onCmdDelete(FXObject*,FXSelector,void*);
	long onCmdMoveUp(FXObject*,FXSelector,void*);
	long onCmdMoveDown(FXObject*,FXSelector,void*);
	long onCmdSelectAll(FXObject*,FXSelector,void*);
	long onCmdClear(FXObject*,FXSelector,void*);
	long onListRightMouse(FXObject*,FXSelector,void* ptr);
	long onCmdPutBack(FXObject*,FXSelector,void*);
  	long onUpdSelectedTable(FXObject*,FXSelector,void*);
	long onCmdSavePlaylist(FXObject*,FXSelector,void*);
	long onCmdOpenPlaylist(FXObject*,FXSelector,void*);
	// directory list
  	long onCmdDirectory(FXObject*,FXSelector,void*);
  	long onCmdUpDirectory(FXObject*,FXSelector,void*);
  	long onCmdNewDir(FXObject*,FXSelector,void*);
	long onCmdDirRename(FXObject*,FXSelector,void*);
  	long onUpdNewDir(FXObject*,FXSelector,void*);
  	long onCmdDirDelete(FXObject*,FXSelector,void*);
	long onDirListPopup(FXObject*,FXSelector,void*);
  	long onCmdMapHost(FXObject*,FXSelector,void*);
  	long onCmdUnmapHost(FXObject*,FXSelector,void*);
	// file list
	long onFileListPopup(FXObject*,FXSelector,void*);
	long onCmdFileListDC(FXObject*,FXSelector,void*);
	long onCmdFileCopy(FXObject*,FXSelector,void*);
	long onCmdFileSymlink(FXObject*,FXSelector,void*);
	long onCmdFileRename(FXObject*,FXSelector,void*);
	long onCmdFileDelete(FXObject*,FXSelector,void*);
	long onCmdFilePlay(FXObject*,FXSelector,void*);
	long onCmdFilePause(FXObject*,FXSelector,void*);
	long onCmdFileStop(FXObject *,FXSelector,void *);
  	long onUpdSelectedFile(FXObject*,FXSelector,void*);
	long onCmdFilePreview(FXObject*,FXSelector,void*);
	long onCmdForceFilePreview(FXObject*,FXSelector,void*);
	long onCmdWideScreen(FXObject*,FXSelector,void*);
	long onCmdIncFilePreview(FXObject*,FXSelector,void*);
	long onCmdDecFilePreview(FXObject*,FXSelector,void*);
	long onCmdClearPreview(FXObject*,FXSelector,void*);
	long onCmdTerminal(FXObject*,FXSelector,void*);
  	long onCmdExtract(FXObject*,FXSelector,void*);
  	long onCmdCompressTar(FXObject*,FXSelector,void*);
  	long onCmdCompressGz(FXObject*,FXSelector,void*);
  	long onCmdCompressBz(FXObject*,FXSelector,void*);
  	long onCmdCompress7z(FXObject*,FXSelector,void*);
  	long onCmdCompressZ(FXObject*,FXSelector,void*);
	long onCmdScanVirus(FXObject*,FXSelector,void*);
	// properties dialog
  	long onCmdProperties(FXObject*,FXSelector,void*);
  	long onUpdCreatedTime(FXObject*,FXSelector,void*);
  	long onUpdModifiedTime(FXObject*,FXSelector,void*);
  	long onUpdFileType(FXObject*,FXSelector,void*);
  	long onUpdFileMimeType(FXObject*,FXSelector,void*);
  	long onUpdFileCommand(FXObject*,FXSelector,void*);	
  	long onUpdFileLocation(FXObject*,FXSelector,void*);
  	long onUpdFileSize(FXObject*,FXSelector,void*);
  	long onUpdFileDesc(FXObject*,FXSelector,void*);
  	long onUpdMovieAspect(FXObject*,FXSelector,void*);
  	long onUpdAudioFormat(FXObject*,FXSelector,void*);
  	long onCmdFilemode(FXObject*,FXSelector,void*);
  	long onUpdFilemode(FXObject*,FXSelector,void*);
  	long onUpdOwner(FXObject*,FXSelector,void*);
  	long onUpdGroup(FXObject*,FXSelector,void*);
	// mimetype dialog
  	long onCmdMimeType(FXObject*,FXSelector,void*);
  	long onCmdOpen(FXObject*,FXSelector,void*);
  	long onCmdOpenWith(FXObject*,FXSelector,void*);
  	long onUpdItemFound(FXObject*,FXSelector,void*);
};

#endif
